@@ -103,7 +103,7 @@ impl PyModel {
         let data = serde_json::to_string(&self.model).map_err(|e| {
             exceptions::PyException::new_err(format!(
                 "Error while attempting to pickle Model: {}",
-                e.to_string()
+                e
             ))
         })?;
         Ok(PyBytes::new(py, data.as_bytes()).to_object(py))
@@ -115,7 +115,7 @@ impl PyModel {
                 self.model = serde_json::from_slice(s.as_bytes()).map_err(|e| {
                     exceptions::PyException::new_err(format!(
                         "Error while attempting to unpickle Model: {}",
-                        e.to_string()
+                        e
                     ))
                 })?;
                 Ok(())
@@ -636,7 +636,7 @@ impl PyWordPiece {
     ///         The path to a :obj:`vocab.txt` file
     ///
     /// Returns:
-    ///     :class:`~tokenizers.models.WordPiece`: And instance of WordPiece loaded from file
+    ///     :class:`~tokenizers.models.WordPiece`: An instance of WordPiece loaded from file
     #[classmethod]
     #[args(kwargs = "**")]
     #[text_signature = "(vocab, **kwargs)"]
@@ -748,9 +748,10 @@ impl PyWordLevel {
     ///         The path to a :obj:`vocab.json` file
     ///
     /// Returns:
-    ///     :class:`~tokenizers.models.WordLevel`: And instance of WordLevel loaded from file
+    ///     :class:`~tokenizers.models.WordLevel`: An instance of WordLevel loaded from file
     #[classmethod]
     #[args(unk_token = "None")]
+    #[text_signature = "(vocab, unk_token)"]
     fn from_file(
         _cls: &PyType,
         py: Python,
