@@ -291,7 +291,9 @@ impl TryFrom<&str> for Template {
 /// [`SpecialToken`]: struct.SpecialToken.html
 #[derive(Debug, Clone, PartialEq, Default, Serialize, Deserialize)]
 #[serde(transparent)]
-pub struct Tokens(pub HashMap<String, SpecialToken>);
+pub struct Tokens(
+    #[serde(serialize_with = "crate::utils::ordered_map")] pub HashMap<String, SpecialToken>,
+);
 
 impl<T: Into<SpecialToken>> From<Vec<T>> for Tokens {
     fn from(v: Vec<T>) -> Self {
@@ -517,21 +519,20 @@ impl TemplateProcessing {
         let mut offsets = Vec::with_capacity(new_len);
         let mut special_tokens_mask = Vec::with_capacity(new_len);
         let mut attention_mask = Vec::with_capacity(new_len);
+        let mut sequence_ranges = HashMap::new();
 
         let pair_overflowing = pair.as_mut().map_or(vec![], |e| e.take_overflowing());
         let mut overflowing = encoding
             .take_overflowing()
             .into_iter()
             .flat_map(|encoding| {
-                let mut overflowings = vec![];
-
                 // 1. The pair itself
-                overflowings.push(self.apply_template(
+                let mut overflowings = vec![self.apply_template(
                     template,
                     encoding.clone(),
                     pair.clone(),
                     add_special_tokens,
-                ));
+                )];
 
                 // 2. Its overflowings
                 for other_o in &pair_overflowing {
@@ -562,10 +563,13 @@ impl TemplateProcessing {
                     id: Sequence::A,
                     type_id,
                 } => {
+                    let seq_start = ids.len();
+                    let seq_end = seq_start + encoding.len();
+                    sequence_ranges.insert(0, seq_start..seq_end);
                     ids.extend(encoding.get_ids());
                     type_ids.extend(std::iter::repeat(type_id).take(encoding.len()));
                     tokens.extend(encoding.get_tokens().iter().map(|s| s.to_owned()));
-                    words.extend(encoding.get_words());
+                    words.extend(encoding.get_word_ids());
                     offsets.extend(encoding.get_offsets());
                     special_tokens_mask.extend(encoding.get_special_tokens_mask());
                     attention_mask.extend(encoding.get_attention_mask());
@@ -575,10 +579,13 @@ impl TemplateProcessing {
                     type_id,
                 } => {
                     let pair = pair.as_ref().expect("Missing pair sequence, checked above");
+                    let seq_start = ids.len();
+                    let seq_end = seq_start + pair.len();
+                    sequence_ranges.insert(1, seq_start..seq_end);
                     ids.extend(pair.get_ids());
                     type_ids.extend(std::iter::repeat(type_id).take(pair.len()));
                     tokens.extend(pair.get_tokens().iter().map(|s| s.to_owned()));
-                    words.extend(pair.get_words());
+                    words.extend(pair.get_word_ids());
                     offsets.extend(pair.get_offsets());
                     special_tokens_mask.extend(pair.get_special_tokens_mask());
                     attention_mask.extend(pair.get_attention_mask());
@@ -609,6 +616,7 @@ impl TemplateProcessing {
             special_tokens_mask,
             attention_mask,
             overflowing,
+            sequence_ranges,
         ))
     }
 }
@@ -645,6 +653,7 @@ impl PostProcessor for TemplateProcessing {
 mod tests {
     use super::*;
     use std::convert::TryInto;
+    use std::iter::FromIterator;
 
     #[test]
     fn piece_serde() {
@@ -776,15 +785,10 @@ mod tests {
     #[test]
     fn tokens_serde() {
         let tokens = Tokens::from(vec![("[CLS]", 1), ("[SEP]", 0)]);
-        let tokens_s = r#"{"[SEP]":{"id":"[SEP]","ids":[0],"tokens":["[SEP]"]},"[CLS]":{"id":"[CLS]","ids":[1],"tokens":["[CLS]"]}}"#;
-        let tokens_s_alt = r#"{"[CLS]":{"id":"[CLS]","ids":[1],"tokens":["[CLS]"]},"[SEP]":{"id":"[SEP]","ids":[0],"tokens":["[SEP]"]}}"#;
+        let tokens_s = r#"{"[CLS]":{"id":"[CLS]","ids":[1],"tokens":["[CLS]"]},"[SEP]":{"id":"[SEP]","ids":[0],"tokens":["[SEP]"]}}"#;
         let tokens_ser = serde_json::to_string(&tokens).unwrap();
-        assert!(tokens_ser == tokens_s || tokens_ser == tokens_s_alt);
+        assert_eq!(tokens_ser, tokens_s);
         assert_eq!(serde_json::from_str::<Tokens>(tokens_s).unwrap(), tokens);
-        assert_eq!(
-            serde_json::from_str::<Tokens>(tokens_s_alt).unwrap(),
-            tokens
-        );
     }
 
     fn get_bert_template() -> TemplateProcessing {
@@ -823,38 +827,12 @@ mod tests {
                     \"id\":\"[SEP]\",\"ids\":[0],\"tokens\":[\"[SEP]\"]\
                 }\
             }}";
-        let template_s_alt = "{\
-            \"type\":\"TemplateProcessing\",\
-            \"single\":[\
-                {\"SpecialToken\":{\"id\":\"[CLS]\",\"type_id\":0}},\
-                {\"Sequence\":{\"id\":\"A\",\"type_id\":0}},\
-                {\"SpecialToken\":{\"id\":\"[SEP]\",\"type_id\":0}}\
-            ],\
-            \"pair\":[\
-                {\"SpecialToken\":{\"id\":\"[CLS]\",\"type_id\":0}},\
-                {\"Sequence\":{\"id\":\"A\",\"type_id\":0}},\
-                {\"SpecialToken\":{\"id\":\"[SEP]\",\"type_id\":0}},\
-                {\"Sequence\":{\"id\":\"B\",\"type_id\":1}},\
-                {\"SpecialToken\":{\"id\":\"[SEP]\",\"type_id\":1}}\
-            ],\
-            \"special_tokens\":{\
-                \"[SEP]\":{\
-                    \"id\":\"[SEP]\",\"ids\":[0],\"tokens\":[\"[SEP]\"]\
-                },\
-                \"[CLS]\":{\
-                    \"id\":\"[CLS]\",\"ids\":[1],\"tokens\":[\"[CLS]\"]\
-                }\
-            }}";
         let template_ser = serde_json::to_string(&template).unwrap();
-        assert!(template_ser == template_s || template_ser == template_s_alt);
+        assert_eq!(template_ser, template_s);
         assert_eq!(
             serde_json::from_str::<TemplateProcessing>(template_s).unwrap(),
             template
         );
-        assert_eq!(
-            serde_json::from_str::<TemplateProcessing>(template_s_alt).unwrap(),
-            template
-        );
     }
 
     #[test]
@@ -886,8 +864,10 @@ mod tests {
             0,
         );
         let pair = Encoding::from_tokens(vec![Token::new(15, "pair".into(), (0, 4))], 0);
+        let single_encoding = processor.process(encoding.clone(), None, true).unwrap();
+        let pair_encoding = processor.process(encoding, Some(pair), true).unwrap();
         assert_eq!(
-            processor.process(encoding.clone(), None, true).unwrap(),
+            single_encoding,
             Encoding::new(
                 vec![1, 12, 14, 0],
                 vec![0, 0, 0, 0],
@@ -901,11 +881,14 @@ mod tests {
                 vec![(0, 0), (0, 5), (6, 11), (0, 0)],
                 vec![1, 0, 0, 1],
                 vec![1, 1, 1, 1],
-                vec![]
+                vec![],
+                HashMap::from_iter(vec![(0, 1..3)]),
             )
         );
+        assert_eq!(single_encoding.token_to_sequence(2), Some(0));
+        assert_eq!(single_encoding.token_to_sequence(3), None);
         assert_eq!(
-            processor.process(encoding, Some(pair), true).unwrap(),
+            pair_encoding,
             Encoding::new(
                 vec![1, 12, 14, 0, 15, 0],
                 vec![0, 0, 0, 0, 1, 1],
@@ -921,9 +904,14 @@ mod tests {
                 vec![(0, 0), (0, 5), (6, 11), (0, 0), (0, 4), (0, 0)],
                 vec![1, 0, 0, 1, 0, 1],
                 vec![1, 1, 1, 1, 1, 1],
-                vec![]
+                vec![],
+                HashMap::from_iter(vec![(0, 1..3), (1, 4..5)]),
             )
         );
+        assert_eq!(pair_encoding.token_to_sequence(2), Some(0));
+        assert_eq!(pair_encoding.token_to_sequence(3), None);
+        assert_eq!(pair_encoding.token_to_sequence(4), Some(1));
+        assert_eq!(pair_encoding.token_to_sequence(5), None);
     }
 
     #[test]
