@@ -396,6 +396,14 @@ impl Tokenizer {
         let content = read_to_string(file)?;
         Ok(serde_json::from_str(&content)?)
     }
+    #[cfg(feature = "http")]
+    pub fn from_pretrained<S: AsRef<str>>(
+        identifier: S,
+        params: Option<crate::utils::from_pretrained::FromPretrainedParameters>,
+    ) -> Result<Self> {
+        let tokenizer_file = crate::utils::from_pretrained::from_pretrained(identifier, params)?;
+        Tokenizer::from_file(tokenizer_file)
+    }
 }
 
 impl std::str::FromStr for Tokenizer {
@@ -866,7 +874,7 @@ where
                     };
                     truncate_encodings(encoding, pair_encoding, &params)?
                 } else {
-                    truncate_encodings(encoding, pair_encoding, &trunc)?
+                    truncate_encodings(encoding, pair_encoding, trunc)?
                 }
             } else {
                 (encoding, pair_encoding)
@@ -917,7 +925,7 @@ where
 
         if let Some(params) = &self.padding {
             // We do the padding here to make sure we handle the batch padding
-            pad_encodings(&mut encodings, &params)?;
+            pad_encodings(&mut encodings, params)?;
         }
 
         Ok(encodings)
@@ -940,7 +948,7 @@ where
 
         if let Some(params) = &self.padding {
             // We do the padding here to make sure we handle the batch padding
-            pad_encodings(&mut encodings, &params)?;
+            pad_encodings(&mut encodings, params)?;
         }
 
         Ok(encodings)
@@ -1118,6 +1126,26 @@ where
     }
 }
 
+impl<M, N, PT, PP, D> TokenizerImpl<M, N, PT, PP, D>
+where
+    M: DeserializeOwned + Model,
+    N: DeserializeOwned + Normalizer,
+    PT: DeserializeOwned + PreTokenizer,
+    PP: DeserializeOwned + PostProcessor,
+    D: DeserializeOwned + Decoder,
+{
+    #[cfg(feature = "http")]
+    /// Instantiate a new Tokenizer from a file hosted on the Hugging Face Hub.
+    /// It expects the `identifier` of a model that includes a `tokenizer.json` file.
+    pub fn from_pretrained<S: AsRef<str>>(
+        identifier: S,
+        params: Option<crate::utils::from_pretrained::FromPretrainedParameters>,
+    ) -> Result<Self> {
+        let tokenizer_file = crate::utils::from_pretrained::from_pretrained(identifier, params)?;
+        TokenizerImpl::from_file(tokenizer_file)
+    }
+}
+
 impl<M, N, PT, PP, D> TokenizerImpl<M, N, PT, PP, D>
 where
     M: Serialize,
@@ -1140,7 +1168,7 @@ where
         let serialized = self.to_string(pretty)?;
 
         let mut file = File::create(path)?;
-        file.write_all(&serialized.as_bytes())?;
+        file.write_all(serialized.as_bytes())?;
 
         Ok(())
     }
