@@ -3,6 +3,11 @@ use serde::{Deserialize, Serialize};
 use std::cmp;
 use std::mem;
 
+pub enum TruncateDirection {
+    Left,
+    Right,
+}
+
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct TruncationParams {
     pub max_length: usize,
@@ -26,8 +31,6 @@ pub enum TruncationError {
     SecondSequenceNotProvided,
     /// We cannot truncate the target sequence enough to respect the provided max length.
     SequenceTooShort,
-    /// We cannot truncate with the given constraints.
-    MaxLengthTooLow,
 }
 
 impl std::fmt::Display for TruncationError {
@@ -41,10 +44,6 @@ impl std::fmt::Display for TruncationError {
                 fmt,
                 "Truncation error: Sequence to truncate too short to respect the provided max_length"
             ),
-            MaxLengthTooLow => write!(
-                fmt,
-                "Truncation error: Specified max length is too low \
-                    to respect the various constraints"),
         }
     }
 }
@@ -73,9 +72,9 @@ pub fn truncate_encodings(
     params: &TruncationParams,
 ) -> Result<(Encoding, Option<Encoding>)> {
     if params.max_length == 0 {
-        encoding.truncate(0, params.stride);
+        encoding.truncate(0, params.stride, TruncateDirection::Right);
         if let Some(other_encoding) = pair_encoding.as_mut() {
-            other_encoding.truncate(0, params.stride);
+            other_encoding.truncate(0, params.stride, TruncateDirection::Right);
         }
         return Ok((encoding, pair_encoding));
     }
@@ -135,10 +134,14 @@ pub fn truncate_encodings(
                 if swap {
                     mem::swap(&mut n1, &mut n2);
                 }
-                encoding.truncate(n1, params.stride);
-                other_encoding.truncate(n2, params.stride);
+                encoding.truncate(n1, params.stride, TruncateDirection::Right);
+                other_encoding.truncate(n2, params.stride, TruncateDirection::Right);
             } else {
-                encoding.truncate(total_length - to_remove, params.stride);
+                encoding.truncate(
+                    total_length - to_remove,
+                    params.stride,
+                    TruncateDirection::Right,
+                );
             }
         }
         TruncationStrategy::OnlyFirst | TruncationStrategy::OnlySecond => {
@@ -152,7 +155,11 @@ pub fn truncate_encodings(
 
             let target_len = target.get_ids().len();
             if target_len > to_remove {
-                target.truncate(target_len - to_remove, params.stride);
+                target.truncate(
+                    target_len - to_remove,
+                    params.stride,
+                    TruncateDirection::Right,
+                );
             } else {
                 return Err(Box::new(TruncationError::SequenceTooShort));
             }
@@ -262,7 +269,7 @@ mod tests {
         n1: usize,
         n2: usize,
     ) {
-        match truncate_encodings(encoding1, Some(encoding2), &params) {
+        match truncate_encodings(encoding1, Some(encoding2), params) {
             Ok((e1, Some(e2))) => {
                 assert!(e1.get_ids().len() == n1);
                 assert!(e2.get_ids().len() == n2);
